@@ -1,22 +1,20 @@
 # -*- coding: utf-8 -*-
+from zope.interface import Interface
+
 from guillotina.interfaces import IFile
 from guillotina.interfaces import IFileField
-from zope.interface import Interface
 
 
 class IGCloudFileField(IFileField):
-    """Field marked as GCloudFileField
-    """
+    """Field marked as GCloudFileField"""
 
 
 # Configuration Utility
 
 
 class IGCloudBlobStore(Interface):
-    """Configuration utility.
-    """
+    """Configuration utility."""
 
 
 class IGCloudFile(IFile):
-    """Marker for a GCloudFile
-    """
+    """Marker for a GCloudFile"""
